@@ -60,8 +60,8 @@ baobab_get_filesystem(baobab_fs *fs)
 	for (i = 0; i < mountlist.number; ++i) {
 		glibtop_fsusage fsusage;
 		glibtop_get_fsusage(&fsusage, mountentries[i].mountdir);
-		/* FIXME: check if not an "excluded" mount point
-		   v.1.1.1 changed bavail with bfree) */
+		
+		 /*  v.1.1.1 changed bavail with bfree) */
 		if (!g_slist_find_custom(baobab.bbExcludedDirs,
 					 mountentries[i].mountdir,
 					 list_find)) {
@@ -378,11 +378,10 @@ baobab_check_dir(const gchar * dirname)
 	gboolean bret = TRUE;
 	
 	info = gnome_vfs_file_info_new();
-	result=gnome_vfs_get_file_info(dirname, info,GNOME_VFS_FILE_INFO_DEFAULT);
-
-	if (info->type == GNOME_VFS_FILE_TYPE_SYMBOLIC_LINK)
-		error_msg = g_strdup_printf(_("%s is a symbolic link"), dirname);
-	else if (info->type != GNOME_VFS_FILE_TYPE_DIRECTORY)
+	result=gnome_vfs_get_file_info(dirname, info,GNOME_VFS_FILE_INFO_DEFAULT |
+				GNOME_VFS_FILE_INFO_FOLLOW_LINKS);
+	
+	if (info->type != GNOME_VFS_FILE_TYPE_DIRECTORY)
 		error_msg = g_strdup_printf(_("%s is not a valid directory"), dirname);
 
 	if (error_msg) {
