@@ -6,11 +6,12 @@
  *  Email
  ****************************************************************************/
 
-#ifndef _BBTHREAD_H
-#define _BBTHREAD_H
+#ifndef BAOBAB_NOTHREAD_H
+#define BAOBAB_NOTHREAD_H
 
 
 	void getDir(gchar *);
 	void searchDir(gchar *, gchar* );
+	gboolean bb_scan_is_local(gchar *);
 
 #endif /* _BBTHREAD_H */
