@@ -128,7 +128,8 @@ on_sort_alfa_activate                  (GtkMenuItem     *menuitem,
                                         gpointer         user_data)
 {
 	if (get_NB_page()==VIEW_TREE) {
-		gtk_tree_sortable_set_sort_column_id((GtkTreeSortable*)baobab.model,0,GTK_SORT_ASCENDING);
+		gtk_tree_sortable_set_sort_column_id((GtkTreeSortable*)baobab.model,
+			COL_DIR_NAME,GTK_SORT_ASCENDING);
 	}
 	if (get_NB_page()==VIEW_SEARCH) {
 		gtk_tree_sortable_set_sort_column_id((GtkTreeSortable*)baobab.model_search,COL_FULLPATH,GTK_SORT_ASCENDING);
@@ -142,7 +143,8 @@ on_by_sort_size_activate               (GtkMenuItem     *menuitem,
                                         gpointer         user_data)
 {
 	if (get_NB_page()==VIEW_TREE) {
-		gtk_tree_sortable_set_sort_column_id((GtkTreeSortable*)baobab.model,5,GTK_SORT_DESCENDING);
+		gtk_tree_sortable_set_sort_column_id((GtkTreeSortable*)baobab.model,
+			COL_H_SIZE,GTK_SORT_DESCENDING);
 	}
 	if (get_NB_page()==VIEW_SEARCH) {
 		gtk_tree_sortable_set_sort_column_id((GtkTreeSortable*)baobab.model_search,COL_SIZE,GTK_SORT_DESCENDING);
@@ -442,12 +444,12 @@ void
 volume_changed (GnomeVFSVolumeMonitor *volume_monitor,
 		  		GnomeVFSVolume *volume)
 {
+		
 		/* filesystem has changed (mounted or unmounted device) */
-		if (!baobab.STOP_SCANNING) {
-			baobab.STOP_SCANNING=TRUE;
-			stop_scan();
-		}
-		on_propstb_clicked(NULL,NULL);
+		baobab_get_filesystem(&g_fs);
+		set_label_scan(&g_fs);
+		if (get_NB_page()==VIEW_TREE) show_label(VIEW_TREE);
+
 }
 	
 void
@@ -482,8 +484,8 @@ contents_changed_cb(GnomeVFSMonitorHandle *handle,
 }
 
 void
-on_propstb_clicked                     (GtkToolButton   *toolbutton,
-                                        gpointer         user_data)
+on_propstb_clicked    (GtkToolButton   *toolbutton,
+                       gpointer         user_data)
 {
 		create_props();
 }
