@@ -211,15 +211,17 @@ fill_props_model(GtkWidget * dlg)
 			gtk_list_store_append (model_props, &iter);	
 			if(strcmp("/",mountentry->mountdir)==0){
 			gtk_list_store_set(model_props, &iter,
-							COL_CHECK,TRUE,
-							COL_DEVICE,mountentry->devname,COL_MOUNT,mountentry->mountdir,
-							COL_CHECK_INCONSISTENT,TRUE,-1);
+					COL_CHECK,TRUE,
+					COL_DEVICE,mountentry->devname,
+					COL_MOUNT,mountentry->mountdir,
+					COL_CHECK_INCONSISTENT,TRUE,-1);
 					}
 				else {
 					gtk_list_store_set(model_props, &iter,
-							COL_CHECK,TRUE,
-							COL_DEVICE,mountentry->devname,COL_MOUNT,mountentry->mountdir,
-							COL_CHECK_INCONSISTENT,FALSE,-1);
+						COL_CHECK,TRUE,
+						COL_DEVICE,mountentry->devname,
+						COL_MOUNT,mountentry->mountdir,
+						COL_CHECK_INCONSISTENT,FALSE,-1);
 				}
 	 }
 	 
