@@ -6,15 +6,10 @@
  *  Email
  ****************************************************************************/
 
-#ifndef _PROPS_H
-#define _PROPS_H
+#ifndef BAOBAB_PROPS_H
+#define BAOBAB_PROPS_H
 
-#ifdef __cplusplus
-extern "C"
-{
-#endif
-
-// pros model columns
+/* pros model columns */
 enum
 {
   COL_CHECK,
@@ -34,8 +29,4 @@ void  props_notify (GConfClient *client,
 void create_props(void);
 	
 
-#ifdef __cplusplus
-}
-#endif
-
 #endif /* _PROPS_H */
