@@ -82,7 +82,7 @@ create_directorytreeview (void)
 	gtk_tree_view_set_headers_visible(GTK_TREE_VIEW(tvw),FALSE);
 	scrolled = glade_xml_get_widget(baobab.main_xml, "scrolledwindow1");
 	gtk_scrolled_window_set_policy(GTK_SCROLLED_WINDOW(scrolled),
-									GTK_POLICY_NEVER,GTK_POLICY_AUTOMATIC);
+				     GTK_POLICY_NEVER,GTK_POLICY_AUTOMATIC);
 	
 	baobab.model = create_model();
 	
@@ -109,6 +109,9 @@ create_model (void)
 					G_TYPE_UINT64		/* COL_H_HARDLINK */
 					);
 	
+	/* Defaults to sort-by-size */
+	gtk_tree_sortable_set_sort_column_id((GtkTreeSortable*)mdl,
+			COL_H_SIZE,GTK_SORT_DESCENDING);
 	return mdl;
 }
 
@@ -180,6 +183,7 @@ create_search_model (void)
 			   COL_FULLPATH, "",	
 			   -1);
 	
-	
+	/* Defaults to sort-by-size */
+	gtk_tree_sortable_set_sort_column_id((GtkTreeSortable*)mdl,COL_SIZE,GTK_SORT_DESCENDING);
 	return mdl;
 }
